NLSL: zaypx.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Functions/Subroutines
zaypx.f90 File Reference

Go to the source code of this file.

## Functions/Subroutines
subroutine | zaypx (x, y, scale, ndim)

## Function/Subroutine Documentation

subroutine zaypx | ( | double complex, dimension(mxdim) | x,
|  | double complex, dimension(mxdim) | y,
|  | double complex | scale,
|  | integer | ndim
| ) |  |

Definition at line 19 of file zaypx.f90.

Here is the caller graph for this function: